/********************************************************************************
** Form generated from reading UI file 'settings.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SETTINGS_H
#define UI_SETTINGS_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSlider>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcolorbutton.h"

QT_BEGIN_NAMESPACE

class Ui_Settings
{
public:
    QHBoxLayout *horizontalLayout_3;
    QFrame *frame;
    QHBoxLayout *horizontalLayout_9;
    QVBoxLayout *verticalLayout_11;
    QGroupBox *groupBox_3;
    QVBoxLayout *verticalLayout_5;
    QCheckBox *kcfg_ComputerPlayer1;
    QGroupBox *groupBox_5;
    QVBoxLayout *verticalLayout_4;
    QRadioButton *kcfg_Kepler1;
    QRadioButton *kcfg_Newton1;
    QVBoxLayout *verticalLayout_3;
    QSlider *kcfg_Skill1;
    QHBoxLayout *horizontalLayout;
    QLabel *label;
    QLabel *label_2;
    QLabel *label_3;
    QGroupBox *groupBox;
    QVBoxLayout *verticalLayout_14;
    QCheckBox *kcfg_ComputerPlayer2;
    QGroupBox *groupBox_6;
    QVBoxLayout *verticalLayout_2;
    QRadioButton *kcfg_Kepler2;
    QRadioButton *kcfg_Newton2;
    QVBoxLayout *verticalLayout;
    QSlider *kcfg_Skill2;
    QHBoxLayout *horizontalLayout_2;
    QLabel *label_9;
    QLabel *label_10;
    QLabel *label_11;
    QCheckBox *kcfg_PauseForComputer;
    QVBoxLayout *verticalLayout_8;
    QGroupBox *groupBox_2;
    QVBoxLayout *verticalLayout_9;
    QSlider *kcfg_CubeDim;
    QHBoxLayout *horizontalLayout_8;
    QLabel *label_4;
    QSpacerItem *horizontalSpacer;
    QLabel *label_5;
    QGroupBox *groupBox_4;
    QVBoxLayout *verticalLayout_6;
    QHBoxLayout *horizontalLayout_4;
    QLabel *label_6;
    KColorButton *kcfg_Color1;
    QHBoxLayout *horizontalLayout_5;
    QLabel *label_7;
    KColorButton *kcfg_Color2;
    QHBoxLayout *horizontalLayout_6;
    QLabel *label_8;
    KColorButton *kcfg_Color0;
    QGroupBox *groupBox1;
    QVBoxLayout *verticalLayout_10;
    QRadioButton *kcfg_AnimationNone;
    QRadioButton *kcfg_AnimationDelay;
    QRadioButton *kcfg_AnimationBlink;
    QRadioButton *kcfg_AnimationSpread;
    QGroupBox *SpeedSlider;
    QVBoxLayout *verticalLayout_7;
    QSlider *kcfg_AnimationSpeed;
    QHBoxLayout *horizontalLayout_7;
    QLabel *label_14;
    QSpacerItem *horizontalSpacer_2;
    QLabel *label_13;
    QCheckBox *kcfg_PauseForStep;

    void setupUi(QWidget *Settings)
    {
        if (Settings->objectName().isEmpty())
            Settings->setObjectName("Settings");
        Settings->resize(547, 624);
        horizontalLayout_3 = new QHBoxLayout(Settings);
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        frame = new QFrame(Settings);
        frame->setObjectName("frame");
        frame->setFrameShape(QFrame::StyledPanel);
        frame->setFrameShadow(QFrame::Raised);
        horizontalLayout_9 = new QHBoxLayout(frame);
        horizontalLayout_9->setObjectName("horizontalLayout_9");
        verticalLayout_11 = new QVBoxLayout();
        verticalLayout_11->setObjectName("verticalLayout_11");
        groupBox_3 = new QGroupBox(frame);
        groupBox_3->setObjectName("groupBox_3");
        verticalLayout_5 = new QVBoxLayout(groupBox_3);
        verticalLayout_5->setObjectName("verticalLayout_5");
        kcfg_ComputerPlayer1 = new QCheckBox(groupBox_3);
        kcfg_ComputerPlayer1->setObjectName("kcfg_ComputerPlayer1");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(kcfg_ComputerPlayer1->sizePolicy().hasHeightForWidth());
        kcfg_ComputerPlayer1->setSizePolicy(sizePolicy);
        kcfg_ComputerPlayer1->setMinimumSize(QSize(0, 30));

        verticalLayout_5->addWidget(kcfg_ComputerPlayer1);

        groupBox_5 = new QGroupBox(groupBox_3);
        groupBox_5->setObjectName("groupBox_5");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Expanding);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(groupBox_5->sizePolicy().hasHeightForWidth());
        groupBox_5->setSizePolicy(sizePolicy1);
        verticalLayout_4 = new QVBoxLayout(groupBox_5);
        verticalLayout_4->setObjectName("verticalLayout_4");
        kcfg_Kepler1 = new QRadioButton(groupBox_5);
        kcfg_Kepler1->setObjectName("kcfg_Kepler1");
        kcfg_Kepler1->setChecked(true);

        verticalLayout_4->addWidget(kcfg_Kepler1);

        kcfg_Newton1 = new QRadioButton(groupBox_5);
        kcfg_Newton1->setObjectName("kcfg_Newton1");

        verticalLayout_4->addWidget(kcfg_Newton1);


        verticalLayout_5->addWidget(groupBox_5);

        verticalLayout_3 = new QVBoxLayout();
        verticalLayout_3->setObjectName("verticalLayout_3");
        kcfg_Skill1 = new QSlider(groupBox_3);
        kcfg_Skill1->setObjectName("kcfg_Skill1");
        kcfg_Skill1->setMaximum(4);
        kcfg_Skill1->setPageStep(1);
        kcfg_Skill1->setSliderPosition(0);
        kcfg_Skill1->setOrientation(Qt::Horizontal);
        kcfg_Skill1->setTickPosition(QSlider::TicksBelow);

        verticalLayout_3->addWidget(kcfg_Skill1);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        label = new QLabel(groupBox_3);
        label->setObjectName("label");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Minimum);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(label->sizePolicy().hasHeightForWidth());
        label->setSizePolicy(sizePolicy2);
        label->setMinimumSize(QSize(0, 20));
        label->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignTop);

        horizontalLayout->addWidget(label);

        label_2 = new QLabel(groupBox_3);
        label_2->setObjectName("label_2");
        label_2->setAlignment(Qt::AlignHCenter|Qt::AlignTop);

        horizontalLayout->addWidget(label_2);

        label_3 = new QLabel(groupBox_3);
        label_3->setObjectName("label_3");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Minimum);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(label_3->sizePolicy().hasHeightForWidth());
        label_3->setSizePolicy(sizePolicy3);
        label_3->setAlignment(Qt::AlignRight|Qt::AlignTop|Qt::AlignTrailing);

        horizontalLayout->addWidget(label_3);


        verticalLayout_3->addLayout(horizontalLayout);


        verticalLayout_5->addLayout(verticalLayout_3);


        verticalLayout_11->addWidget(groupBox_3);

        groupBox = new QGroupBox(frame);
        groupBox->setObjectName("groupBox");
        verticalLayout_14 = new QVBoxLayout(groupBox);
        verticalLayout_14->setObjectName("verticalLayout_14");
        kcfg_ComputerPlayer2 = new QCheckBox(groupBox);
        kcfg_ComputerPlayer2->setObjectName("kcfg_ComputerPlayer2");
        sizePolicy.setHeightForWidth(kcfg_ComputerPlayer2->sizePolicy().hasHeightForWidth());
        kcfg_ComputerPlayer2->setSizePolicy(sizePolicy);
        kcfg_ComputerPlayer2->setMinimumSize(QSize(0, 30));

        verticalLayout_14->addWidget(kcfg_ComputerPlayer2);

        groupBox_6 = new QGroupBox(groupBox);
        groupBox_6->setObjectName("groupBox_6");
        sizePolicy1.setHeightForWidth(groupBox_6->sizePolicy().hasHeightForWidth());
        groupBox_6->setSizePolicy(sizePolicy1);
        groupBox_6->setFlat(false);
        verticalLayout_2 = new QVBoxLayout(groupBox_6);
        verticalLayout_2->setObjectName("verticalLayout_2");
        kcfg_Kepler2 = new QRadioButton(groupBox_6);
        kcfg_Kepler2->setObjectName("kcfg_Kepler2");
        kcfg_Kepler2->setChecked(true);

        verticalLayout_2->addWidget(kcfg_Kepler2);

        kcfg_Newton2 = new QRadioButton(groupBox_6);
        kcfg_Newton2->setObjectName("kcfg_Newton2");

        verticalLayout_2->addWidget(kcfg_Newton2);


        verticalLayout_14->addWidget(groupBox_6);

        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName("verticalLayout");
        kcfg_Skill2 = new QSlider(groupBox);
        kcfg_Skill2->setObjectName("kcfg_Skill2");
        kcfg_Skill2->setMaximum(4);
        kcfg_Skill2->setPageStep(1);
        kcfg_Skill2->setOrientation(Qt::Horizontal);
        kcfg_Skill2->setTickPosition(QSlider::TicksBelow);

        verticalLayout->addWidget(kcfg_Skill2);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        label_9 = new QLabel(groupBox);
        label_9->setObjectName("label_9");
        sizePolicy2.setHeightForWidth(label_9->sizePolicy().hasHeightForWidth());
        label_9->setSizePolicy(sizePolicy2);
        label_9->setMinimumSize(QSize(0, 20));
        label_9->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignTop);

        horizontalLayout_2->addWidget(label_9);

        label_10 = new QLabel(groupBox);
        label_10->setObjectName("label_10");
        label_10->setAlignment(Qt::AlignHCenter|Qt::AlignTop);

        horizontalLayout_2->addWidget(label_10);

        label_11 = new QLabel(groupBox);
        label_11->setObjectName("label_11");
        sizePolicy3.setHeightForWidth(label_11->sizePolicy().hasHeightForWidth());
        label_11->setSizePolicy(sizePolicy3);
        label_11->setAlignment(Qt::AlignRight|Qt::AlignTop|Qt::AlignTrailing);

        horizontalLayout_2->addWidget(label_11);


        verticalLayout->addLayout(horizontalLayout_2);


        verticalLayout_14->addLayout(verticalLayout);


        verticalLayout_11->addWidget(groupBox);

        kcfg_PauseForComputer = new QCheckBox(frame);
        kcfg_PauseForComputer->setObjectName("kcfg_PauseForComputer");

        verticalLayout_11->addWidget(kcfg_PauseForComputer);


        horizontalLayout_9->addLayout(verticalLayout_11);

        verticalLayout_8 = new QVBoxLayout();
        verticalLayout_8->setObjectName("verticalLayout_8");
        groupBox_2 = new QGroupBox(frame);
        groupBox_2->setObjectName("groupBox_2");
        verticalLayout_9 = new QVBoxLayout(groupBox_2);
        verticalLayout_9->setObjectName("verticalLayout_9");
        kcfg_CubeDim = new QSlider(groupBox_2);
        kcfg_CubeDim->setObjectName("kcfg_CubeDim");
        sizePolicy.setHeightForWidth(kcfg_CubeDim->sizePolicy().hasHeightForWidth());
        kcfg_CubeDim->setSizePolicy(sizePolicy);
        kcfg_CubeDim->setMinimum(3);
        kcfg_CubeDim->setMaximum(15);
        kcfg_CubeDim->setPageStep(1);
        kcfg_CubeDim->setValue(6);
        kcfg_CubeDim->setOrientation(Qt::Horizontal);
        kcfg_CubeDim->setTickPosition(QSlider::TicksBelow);

        verticalLayout_9->addWidget(kcfg_CubeDim);

        horizontalLayout_8 = new QHBoxLayout();
        horizontalLayout_8->setObjectName("horizontalLayout_8");
        label_4 = new QLabel(groupBox_2);
        label_4->setObjectName("label_4");
        label_4->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignTop);

        horizontalLayout_8->addWidget(label_4);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_8->addItem(horizontalSpacer);

        label_5 = new QLabel(groupBox_2);
        label_5->setObjectName("label_5");
        label_5->setAlignment(Qt::AlignRight|Qt::AlignTop|Qt::AlignTrailing);

        horizontalLayout_8->addWidget(label_5);


        verticalLayout_9->addLayout(horizontalLayout_8);


        verticalLayout_8->addWidget(groupBox_2);

        groupBox_4 = new QGroupBox(frame);
        groupBox_4->setObjectName("groupBox_4");
        verticalLayout_6 = new QVBoxLayout(groupBox_4);
        verticalLayout_6->setObjectName("verticalLayout_6");
        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        label_6 = new QLabel(groupBox_4);
        label_6->setObjectName("label_6");

        horizontalLayout_4->addWidget(label_6);

        kcfg_Color1 = new KColorButton(groupBox_4);
        kcfg_Color1->setObjectName("kcfg_Color1");

        horizontalLayout_4->addWidget(kcfg_Color1);


        verticalLayout_6->addLayout(horizontalLayout_4);

        horizontalLayout_5 = new QHBoxLayout();
        horizontalLayout_5->setObjectName("horizontalLayout_5");
        label_7 = new QLabel(groupBox_4);
        label_7->setObjectName("label_7");

        horizontalLayout_5->addWidget(label_7);

        kcfg_Color2 = new KColorButton(groupBox_4);
        kcfg_Color2->setObjectName("kcfg_Color2");

        horizontalLayout_5->addWidget(kcfg_Color2);


        verticalLayout_6->addLayout(horizontalLayout_5);

        horizontalLayout_6 = new QHBoxLayout();
        horizontalLayout_6->setObjectName("horizontalLayout_6");
        label_8 = new QLabel(groupBox_4);
        label_8->setObjectName("label_8");

        horizontalLayout_6->addWidget(label_8);

        kcfg_Color0 = new KColorButton(groupBox_4);
        kcfg_Color0->setObjectName("kcfg_Color0");

        horizontalLayout_6->addWidget(kcfg_Color0);


        verticalLayout_6->addLayout(horizontalLayout_6);


        verticalLayout_8->addWidget(groupBox_4);

        groupBox1 = new QGroupBox(frame);
        groupBox1->setObjectName("groupBox1");
        verticalLayout_10 = new QVBoxLayout(groupBox1);
        verticalLayout_10->setObjectName("verticalLayout_10");
        kcfg_AnimationNone = new QRadioButton(groupBox1);
        kcfg_AnimationNone->setObjectName("kcfg_AnimationNone");
        QSizePolicy sizePolicy4(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy4.setHorizontalStretch(0);
        sizePolicy4.setVerticalStretch(0);
        sizePolicy4.setHeightForWidth(kcfg_AnimationNone->sizePolicy().hasHeightForWidth());
        kcfg_AnimationNone->setSizePolicy(sizePolicy4);

        verticalLayout_10->addWidget(kcfg_AnimationNone);

        kcfg_AnimationDelay = new QRadioButton(groupBox1);
        kcfg_AnimationDelay->setObjectName("kcfg_AnimationDelay");
        sizePolicy4.setHeightForWidth(kcfg_AnimationDelay->sizePolicy().hasHeightForWidth());
        kcfg_AnimationDelay->setSizePolicy(sizePolicy4);

        verticalLayout_10->addWidget(kcfg_AnimationDelay);

        kcfg_AnimationBlink = new QRadioButton(groupBox1);
        kcfg_AnimationBlink->setObjectName("kcfg_AnimationBlink");
        sizePolicy4.setHeightForWidth(kcfg_AnimationBlink->sizePolicy().hasHeightForWidth());
        kcfg_AnimationBlink->setSizePolicy(sizePolicy4);

        verticalLayout_10->addWidget(kcfg_AnimationBlink);

        kcfg_AnimationSpread = new QRadioButton(groupBox1);
        kcfg_AnimationSpread->setObjectName("kcfg_AnimationSpread");
        sizePolicy4.setHeightForWidth(kcfg_AnimationSpread->sizePolicy().hasHeightForWidth());
        kcfg_AnimationSpread->setSizePolicy(sizePolicy4);
        kcfg_AnimationSpread->setChecked(true);

        verticalLayout_10->addWidget(kcfg_AnimationSpread);


        verticalLayout_8->addWidget(groupBox1);

        SpeedSlider = new QGroupBox(frame);
        SpeedSlider->setObjectName("SpeedSlider");
        SpeedSlider->setCheckable(false);
        verticalLayout_7 = new QVBoxLayout(SpeedSlider);
        verticalLayout_7->setObjectName("verticalLayout_7");
        kcfg_AnimationSpeed = new QSlider(SpeedSlider);
        kcfg_AnimationSpeed->setObjectName("kcfg_AnimationSpeed");
        kcfg_AnimationSpeed->setMinimum(1);
        kcfg_AnimationSpeed->setMaximum(10);
        kcfg_AnimationSpeed->setSingleStep(1);
        kcfg_AnimationSpeed->setPageStep(1);
        kcfg_AnimationSpeed->setValue(4);
        kcfg_AnimationSpeed->setSliderPosition(4);
        kcfg_AnimationSpeed->setOrientation(Qt::Horizontal);
        kcfg_AnimationSpeed->setInvertedAppearance(false);
        kcfg_AnimationSpeed->setTickPosition(QSlider::TicksBelow);
        kcfg_AnimationSpeed->setTickInterval(0);

        verticalLayout_7->addWidget(kcfg_AnimationSpeed);

        horizontalLayout_7 = new QHBoxLayout();
        horizontalLayout_7->setObjectName("horizontalLayout_7");
        label_14 = new QLabel(SpeedSlider);
        label_14->setObjectName("label_14");
        label_14->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignTop);

        horizontalLayout_7->addWidget(label_14);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_7->addItem(horizontalSpacer_2);

        label_13 = new QLabel(SpeedSlider);
        label_13->setObjectName("label_13");
        label_13->setAlignment(Qt::AlignRight|Qt::AlignTop|Qt::AlignTrailing);

        horizontalLayout_7->addWidget(label_13);


        verticalLayout_7->addLayout(horizontalLayout_7);


        verticalLayout_8->addWidget(SpeedSlider);

        kcfg_PauseForStep = new QCheckBox(frame);
        kcfg_PauseForStep->setObjectName("kcfg_PauseForStep");

        verticalLayout_8->addWidget(kcfg_PauseForStep);


        horizontalLayout_9->addLayout(verticalLayout_8);


        horizontalLayout_3->addWidget(frame);


        retranslateUi(Settings);

        QMetaObject::connectSlotsByName(Settings);
    } // setupUi

    void retranslateUi(QWidget *Settings)
    {
        groupBox_3->setTitle(tr2i18n("Computer Player 1", nullptr));
        kcfg_ComputerPlayer1->setText(tr2i18n("Playing now", nullptr));
        groupBox_5->setTitle(tr2i18n("Style of Play", nullptr));
        kcfg_Kepler1->setText(tr2i18n("Kepler", nullptr));
        kcfg_Newton1->setText(tr2i18n("Newton", nullptr));
        label->setText(tr2i18n("Beginner", nullptr));
        label_2->setText(tr2i18n("Average", nullptr));
        label_3->setText(tr2i18n("Expert", nullptr));
        groupBox->setTitle(tr2i18n("Computer Player 2", nullptr));
        kcfg_ComputerPlayer2->setText(tr2i18n("Playing now", nullptr));
        groupBox_6->setTitle(tr2i18n("Style of Play", nullptr));
        kcfg_Kepler2->setText(tr2i18n("Kepler", nullptr));
        kcfg_Newton2->setText(tr2i18n("Newton", nullptr));
        label_9->setText(tr2i18n("Beginner", nullptr));
        label_10->setText(tr2i18n("Average", nullptr));
        label_11->setText(tr2i18n("Expert", nullptr));
        kcfg_PauseForComputer->setText(tr2i18n("Pause before each computer move", nullptr));
        groupBox_2->setTitle(tr2i18n("Board Size", nullptr));
        label_4->setText(tr2i18n("3x3", nullptr));
        label_5->setText(tr2i18n("15x15", nullptr));
        groupBox_4->setTitle(tr2i18n("Players' Colors", nullptr));
        label_6->setText(tr2i18n("Player 1:", nullptr));
        label_7->setText(tr2i18n("Player 2:", nullptr));
        label_8->setText(tr2i18n("Neutral:", nullptr));
        groupBox1->setTitle(tr2i18n("Cascade Move Display", nullptr));
        kcfg_AnimationNone->setText(tr2i18n("None (no pauses)", nullptr));
        kcfg_AnimationDelay->setText(tr2i18n("Darken and pause", nullptr));
        kcfg_AnimationBlink->setText(tr2i18n("Blink rapidly", nullptr));
        kcfg_AnimationSpread->setText(tr2i18n("Scatter dots", nullptr));
        SpeedSlider->setTitle(tr2i18n("Cascade Move Time", nullptr));
        label_14->setText(tr2i18n("Short", nullptr));
        label_13->setText(tr2i18n("Long", nullptr));
        kcfg_PauseForStep->setText(tr2i18n("Pause before each cascade step", nullptr));
        (void)Settings;
    } // retranslateUi

};

namespace Ui {
    class Settings: public Ui_Settings {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SETTINGS_H

